<a id="mypy-boto3-amp"></a>

# mypy-boto3-amp

[![PyPI - mypy-boto3-amp](https://img.shields.io/pypi/v/mypy-boto3-amp.svg?color=blue)](https://pypi.org/project/mypy-boto3-amp)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-amp.svg?color=blue)](https://pypi.org/project/mypy-boto3-amp)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-amp?color=blue)](https://pypistats.org/packages/mypy-boto3-amp)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.PrometheusService 1.18.20](https://boto3.amazonaws.com/v1/documentation/api/1.18.20/reference/services/amp.html#PrometheusService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-amp docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-amp](#mypy-boto3-amp)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `PrometheusService` service.

```bash
python -m pip install boto3-stubs[amp]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[amp]` in your environment:
  `python -m pip install 'boto3-stubs[amp]'`

Both type checking and auto-complete should work for `PrometheusService`
service. No explicit type annotations required, write your `boto3` code as
usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[amp]` in your environment:
  `python -m pip install 'boto3-stubs[amp]'`

Both type checking and auto-complete should work for `PrometheusService`
service. No explicit type annotations required, write your `boto3` code as
usual. Auto-complete can be slow on big projects or if you have a lot of
installed `boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[amp]` in your environment:
  `python -m pip install 'boto3-stubs[amp]'`
- Run `mypy` as usual

Type checking should work for `PrometheusService` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[amp]` in your environment:
  `python -m pip install 'boto3-stubs[amp]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `PrometheusService` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`PrometheusServiceClient` provides annotations for `boto3.client("amp")`.

```python
import boto3

from mypy_boto3_amp import PrometheusServiceClient

client: PrometheusServiceClient = boto3.client("amp")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: PrometheusServiceClient = session.client("amp")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_amp.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_amp import PrometheusServiceClient
from mypy_boto3_amp.paginator import (
    ListWorkspacesPaginator,
)

client: PrometheusServiceClient = boto3.client("amp")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_workspaces_paginator: ListWorkspacesPaginator = client.get_paginator("list_workspaces")
```

<a id="literals"></a>

### Literals

`mypy_boto3_amp.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_amp.literals import (
    ListWorkspacesPaginatorName,
    WorkspaceStatusCodeType,
)

def check_value(value: ListWorkspacesPaginatorName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_amp.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_amp.type_defs import (
    CreateWorkspaceRequestRequestTypeDef,
    CreateWorkspaceResponseTypeDef,
    DeleteWorkspaceRequestRequestTypeDef,
    DescribeWorkspaceRequestRequestTypeDef,
    DescribeWorkspaceResponseTypeDef,
    ListWorkspacesRequestRequestTypeDef,
    ListWorkspacesResponseTypeDef,
    PaginatorConfigTypeDef,
    ResponseMetadataTypeDef,
    UpdateWorkspaceAliasRequestRequestTypeDef,
    WorkspaceDescriptionTypeDef,
    WorkspaceStatusTypeDef,
    WorkspaceSummaryTypeDef,
)

def get_structure() -> CreateWorkspaceRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-amp` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-amp docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
